pub enum TransactionContents {
LedgerGrpc(CheckpointedTransaction),
ExecutedTransaction(ExecutedTransactionData),
}Expand description
A wrapper for the contents of a transaction, either from Ledger gRPC or just executed.
Variants
LedgerGrpc(CheckpointedTransaction)
ExecutedTransaction(ExecutedTransactionData)
Implementations
Sourceimpl TransactionContents
impl TransactionContents
pub fn from_executed_transaction( executed_transaction: &ExecutedTransaction, transaction_data: TransactionData, signatures: Vec<GenericSignature>, ) -> Result<Self>
pub fn data(&self) -> Result<TransactionData>
pub fn digest(&self) -> Result<TransactionDigest>
pub fn effects_digest(&self) -> Result<TransactionEffectsDigest>
pub fn signatures(&self) -> Result<Vec<GenericSignature>>
pub fn effects(&self) -> Result<TransactionEffects>
Sourcepub fn events(&self) -> Result<Vec<Arc<Event>>>
pub fn events(&self) -> Result<Vec<Arc<Event>>>
Returns the events for this transaction. Each Event is wrapped in an Arc so
callers fanning the same transaction out to multiple consumers (e.g., subscription
resolvers serving different subscribers) share the underlying event allocation
rather than each performing a deep clone.
pub fn balance_changes(&self) -> &[BalanceChange]
Sourcepub fn cached_proto_effects(&self) -> Option<&TransactionEffects>
pub fn cached_proto_effects(&self) -> Option<&TransactionEffects>
The proto TransactionEffects cached from a gRPC execution or streaming response, if any.
Sourcepub async fn proto_effects(
&self,
kv_loader: &KvLoader,
) -> Result<TransactionEffects>
pub async fn proto_effects( &self, kv_loader: &KvLoader, ) -> Result<TransactionEffects>
Returns the proto TransactionEffects.
Prefers the proto cached from an execution or streaming response (rendered by the fullnode). Otherwise retrieve the rendered effects from kv.
Sourcepub fn proto_transaction(&self) -> Result<Transaction>
pub fn proto_transaction(&self) -> Result<Transaction>
Returns the proto Transaction.
For ExecutedTransaction, returns the cached proto from gRPC. For other sources, converts native transaction to proto.
pub fn raw_transaction(&self) -> Result<Vec<u8>>
pub fn raw_effects(&self) -> Result<Vec<u8>>
pub fn timestamp_ms(&self) -> Option<u64>
pub fn cp_sequence_number(&self) -> Option<u64>